features/curl_detail/presentation/widget/action_button library
Classes
- ActionButton
-
The
ActionButtonwidget is a stateless widget that provides a popup menu with various actions related to a cURL request. The actions include copying the cURL command, sharing the cURL command, sharing detailed request and response data, and saving the detailed data to a file and sharing the file.