CurlLogs class

Constructors

CurlLogs()

Properties

hashCode int
The hash code for this object.
no setterinherited
isAlreadyOpen bool
getter/setter pair
items List<CurlModel>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addItem(CurlModel model) → void
clear() → void
getCurlModelByUri(Uri uri) CurlModel?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace({required CurlModel replace, required CurlModel save}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CurlLogs
no setter