ShakerDioDetect class

A utility class to detect shake gestures using the device's accelerometer and open the ListCurlScreen when a shake is detected.

Constructors

ShakerDioDetect()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detectShakeAndOpenListCurlScreen({required BuildContext? buildContext, required GlobalKey<NavigatorState>? navigatorKey, double shakeThresholdGravity = 1}) → void
Listens for shake gestures and opens the ListCurlScreen if a shake is detected.