CurlLogs class
Constructors
- CurlLogs()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAlreadyOpen ↔ bool
-
getter/setter pair
-
items
→ List<
CurlModel> -
final
- maxItems ↔ int
-
Numero massimo di richieste in memoria (più vecchie eliminate).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addItem(
CurlModel model) → void -
clear(
) → void -
getById(
String id) → CurlModel? -
getCurlModelByUri(
Uri uri) → CurlModel? -
markClosed(
) → void - Chiude lo stato "inspector già aperto" (es. dopo pop lista).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
{required CurlModel replace, required CurlModel save}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited