Utils class
Utility class providing various helper methods.
Constructors
- Utils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
calculateTimeBetweenTwoDate(
DateTime dateTimeFirst, DateTime dateTimeSecond) → String - Calculates the time difference between two dates and formats it as a string.
-
copyCurl(
CurlModel request, BuildContext context) → void - Copies the generated cURL command to the clipboard and shows a snackbar.
-
getCurl(
CurlModel request) → String - Generates a cURL command string from a CurlModel request.
-
getCurlInputBody(
dynamic data) → String - Encodes the input body data for a cURL command.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited